@@ -4,7 +4,7 @@ import six
 import sqlalchemy as sa
 
 
-__version__ = '0.4.1'
+__version__ = '0.4.2'
 
 
 class Column(sa.Column):
@@ -100,13 +100,14 @@ class ModelConfigurator(object):
         if column.info.get('auto_now'):
             column.default = sa.schema.ColumnDefault(datetime.utcnow)
             if not column.server_default:
+                # Does not support MySQL < 5.6.5
                 column.server_default = sa.schema.DefaultClause(sa.func.now())
 
     def assign_int_defaults(self, column):
         """
         Assigns int column server_default based on column default value
         """
-        if column.default is not None:
+        if column.default is not None and hasattr(column.default, 'arg'):
             if (isinstance(column.default.arg, six.text_type) or
                     isinstance(column.default.arg, six.integer_types)):
                 column.server_default = sa.schema.DefaultClause(
